
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_convert_Output_UTF8__
#define __gnu_gcj_convert_Output_UTF8__

#pragma interface

#include <gnu/gcj/convert/UnicodeToBytes.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace convert
      {
          class Output_UTF8;
      }
    }
  }
}

class gnu::gcj::convert::Output_UTF8 : public ::gnu::gcj::convert::UnicodeToBytes
{

public:
  Output_UTF8();
  virtual ::java::lang::String * getName();
  virtual jint write(JArray< jchar > *, jint, jint);
  virtual jboolean havePendingBytes();
  jboolean __attribute__((aligned(__alignof__( ::gnu::gcj::convert::UnicodeToBytes)))) standardUTF8;
public: // actually package-private
  jchar hi_part;
  jint value;
  jint bytes_todo;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_gcj_convert_Output_UTF8__
