
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_xlib_XColor__
#define __gnu_gcj_xlib_XColor__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
        class RawData;
      namespace xlib
      {
          class XColor;
      }
    }
  }
}

class gnu::gcj::xlib::XColor : public ::java::lang::Object
{

public:
  XColor(jint, jint, jint);
  XColor();
private:
  void init();
public: // actually protected
  void finalize();
public:
  void setRGB(jint, jint, jint);
  jint getRed();
  jint getGreen();
  jint getBlue();
  jbyte getFlags();
  jlong getPixelValue();
public: // actually package-private
  ::gnu::gcj::RawData * __attribute__((aligned(__alignof__( ::java::lang::Object)))) structure;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_gcj_xlib_XColor__
